@@ -9,6 +9,8 @@
 #ifndef KWINCONFIG_H
 #define KWINCONFIG_H
 
+#define KWIN_PLUGIN_VERSION_STRING "5.23.4"
+
 /*
 
  These should be primarily used to detect what kind of compositing
@@ -16,9 +18,6 @@
 
 */
 
-/* KWIN_HAVE_XRENDER_COMPOSITING - whether XRender-based compositing support is available */
-#define KWIN_HAVE_XRENDER_COMPOSITING
-
 #define HAVE_EPOXY_GLX 1
 
 #define HAVE_DL_LIBRARY 1
